@@ -101,6 +101,9 @@ def clear_all(self):
 				'FLRL_WTR_DSPLY':0,
 				'WD_DSPLY':0,
 				'CHKSTND_SPLY':0,
+				'Expiry':None,
+				'BestBy':None,
+				'AquisitionDate':None,
 				})
 			session.commit()
 			session.flush()
