@@ -7,6 +7,26 @@ preloader={
 						'desc':f'find the volume of height*width*length without dimensions',
 						'exec':volume
 					},
+	f'{uuid1()}':{
+						'cmds':['value from total mass','vftm'],
+						'desc':f'give an estimated total value for mass of currency ((1/unitMass)*ValueOfUnit)*TotalMassOfUnitToBeCounted',
+						'exec':TotalCurrencyFromMass
+					},
+	f'{uuid1()}':{
+						'cmds':['base value from mass','bvfm'],
+						'desc':f'get base value for each coin to use as the price so qty may be the gram value (1/unitMass)*ValueOfUnit',
+						'exec':BaseCurrencyValueFromMass
+					},
+	f'{uuid1()}':{
+						'cmds':['us currency mass','us cnc'],
+						'desc':f'get us currency mass values',
+						'exec':USCurrencyMassValues
+					},
+	f'{uuid1()}':{
+						'cmds':['drgs','drugs','drug-select','drug select'],
+						'desc':f'return a selected drug text',
+						'exec':drug_text
+					},
 	f'{uuid1()}':{
 						'cmds':['volume pint',],
 						'desc':f'find the volume of height*width*length using pint to normalize the values',
