@@ -1612,7 +1612,7 @@ def ndtp():
             }
             fd=FormBuilder(data=fields,passThruText=msg)
             if fd is None:
-                exit(1)
+                return
             
             mph=fd['speed']
             distance=fd['distance']
@@ -1641,3 +1641,149 @@ def ndtp():
             return msg
         except Exception as e:
             print(e)
+
+def drug_text():
+    while True:
+        try:
+            drug_names=[
+            'thc flower',
+            'thc vape',
+
+            'thca flower',
+            'thca vape',
+
+            'caffiene',
+            'caffiene+taurine',
+            'caffiene+beta_alanine',
+
+            'alcohol',
+            'alcohol+thc flower',
+            'alcohol+thca flower',
+            
+            'caffiene+thca flower+menthol',
+            'caffiene+thc flower+menthol',
+            ]
+            extra_drugs=detectGetOrSet("extra_drugs","extra_drugs.csv",setValue=False,literal=True)
+            if extra_drugs:
+                extra_drugs=Path(extra_drugs)
+
+
+                if extra_drugs.exists():
+                    with extra_drugs.open("r") as fileio:
+                        reader=csv.reader(fileio,delimiter=',')
+                        for line in reader:
+                            for sub in line:
+                                if sub not in ['',]:
+                                    drug_names.append(sub)
+                                    
+
+
+            htext=[]
+            cta=len(drug_names)
+            for num,i in enumerate(drug_names):
+                htext.append(std_colorize(i,num,cta))
+            htext='\n'.join(htext)
+            print(htext)
+            which=Control(func=FormBuilderMkText,ptext="which index?",helpText=htext,data="integer")
+            if which in [None,'NaN']:
+                return
+
+            return drug_names[which]
+        except Exception as e:
+            print(e)
+            continue
+
+def TotalCurrencyFromMass():
+    msg=''
+    while True:
+        try:
+            fields={
+                '1 Unit Mass(Grams)':{
+                'type':'dec.dec',
+                'default':2.50,
+                },
+                '1 Unit Value($)':{
+                'type':'dec.dec',
+                'default':0.01
+                },
+                'Total Unit Mass (Total Coin/Bill Mass)':{
+                'type':'dec.dec',
+                'default':0.0
+                }
+            }
+            fd=FormBuilder(data=fields,passThruText=msg)
+            if fd is None:
+                return
+            value=(decc(1/fd['1 Unit Mass(Grams)'])*decc(fd['1 Unit Value($)']))*decc(fd['Total Unit Mass (Total Coin/Bill Mass)'])
+            return value
+        except Exception as e:
+            print(e)
+
+def BaseCurrencyValueFromMass():
+    msg=''
+    while True:
+        try:
+            fields={
+                '1 Unit Mass(Grams)':{
+                'type':'dec.dec',
+                'default':2.50,
+                },
+                '1 Unit Value($)':{
+                'type':'dec.dec',
+                'default':0.01
+                }
+            }
+            fd=FormBuilder(data=fields,passThruText=msg)
+            if fd is None:
+                return
+            value=(decc(1/fd['1 Unit Mass(Grams)'])*decc(fd['1 Unit Value($)']))
+            return value
+        except Exception as e:
+            print(e)
+
+
+def USCurrencyMassValues():
+    while True:
+        try:
+            drug_names={
+            'Mass(Grams) - 1 Dollar Coin/1.0':decc(8.1),
+            'Mass(Grams) - Half Dollar/0.50':decc(11.340),
+            'Mass(Grams) - Quarter/0.25':decc(5.670),
+            'Mass(Grams) - Nickel/0.05':decc(5.0),
+            'Mass(Grams) - Dime/0.10':decc(2.268),
+            'Mass(Grams) - Penny/0.01':decc(2.5),
+            'Mass(Grams) - Bill($1/$2/$5/$10/$20/$50/$100':decc(1),
+
+            'Value for Mass(Grams) - 1 Dollar Coin/8.1 Grams':1.00,
+            'Value for Mass(Grams) - Half Dollar/11.340 Grams':0.50,
+            'Value for Mass(Grams) - Quarter/5.670 Grams':0.25,
+            'Value for Mass(Grams) - Nickel/5 Grams':0.05,
+            'Value for Mass(Grams) - Dime/2.268 Grams':0.10,
+            'Value for Mass(Grams) - Penny/2.5 Grams':0.01,
+            'Value for Mass(Grams) - 1$ Bill/1 Grams':1,
+            'Value for Mass(Grams) - 2$ Bill/1 Grams':2,
+            'Value for Mass(Grams) - 5$ Bill/1 Grams':5,
+            'Value for Mass(Grams) - 10$ Bill/1 Grams':10,
+            'Value for Mass(Grams) - 20$ Bill/1 Grams':20,
+            'Value for Mass(Grams) - 50$ Bill/1 Grams':50,
+            'Value for Mass(Grams) - 100$ Bill/1 Grams':100,
+            }
+            
+
+            keys=[]
+            htext=[]
+            cta=len(drug_names)
+            for num,i in enumerate(drug_names):
+                msg=f'{i} -> {drug_names[i]}'
+                htext.append(std_colorize(msg,num,cta))
+                keys.append(i)
+            htext='\n'.join(htext)
+            print(htext)
+            which=Control(func=FormBuilderMkText,ptext="which index?",helpText=htext,data="integer")
+            if which in [None,'NaN']:
+                return
+            return drug_names[keys[which]]
+            
+        except Exception as e:
+            print(e)
+            continue
\ No newline at end of file
